--------------------------------------------------------------------------------
-- LAB1_2 - CSD 
-- http://digsys.upc.edu
--------------------------------------------------------------------------------
-- An example of a simple circuit for running a tutorial on VHDL and EDA tools
-- equations (structural)

-- Step 6 in VHDL EDA design flow ---> Programming the prototyping board
--------------------------------------------------------------------------------
-- NOTE: The port naming are adapted to the active levels of the DE10-Lite Board 
-- Active high inputs and outputs

-- Manual: https://digsys.upc.edu/csd/chips/Terasic/DE10-Lite_User_Manual.pdf

-- KEY1 and KEY0 are active-low push-buttons  (not used in this application)

-- Switches SW(3..0) --> D(1), D(0), A, B
-- LED outputs are active-high
-- LED2 is output W
-- Other LED connected to '0' (OFF, not used)

-- NOTE: In the same way, we can set OFF all the six 7-segment displays
-- HEX5(7..0), HEX4(7..0), .. HEX0(7..0), they are common-anode (active-low)

-- This adaptation is a multiple-file design as explained in P3 
-- (components + signals).

-- This adaptation is a translation of the schematic at: 
-- https://digsys.upc.edu/csd/P01/lab01_2/lab1_2.html 
--------------------------------------------------------------------------------

LIBRARY ieee;
USE  IEEE.STD_LOGIC_1164.all;

ENTITY Circuit_W_top IS
	PORT (
		D		: IN STD_LOGIC_VECTOR(1 DOWNTO 0); --> Sw3, Sw2
		A,B		: IN STD_LOGIC;      -->  Sw1, Sw0
		
		W		: OUT STD_LOGIC; --> Connected to LED2
		
--The active-low not used LED will be set --> OFF
		LED0, LED1, LED3, LED4, LED5, LED6, LED7, LED8, LED9	: OUT STD_LOGIC

	);
END Circuit_W_top; 

ARCHITECTURE DE10_Lite_MAX10_adaptation OF Circuit_W_top IS
	
-- The elemental components to be used:
	COMPONENT Circuit_W IS  
		PORT (
			D		: IN STD_LOGIC_VECTOR(1 DOWNTO 0); 
			A,B		: IN STD_LOGIC;      
			W		: OUT STD_LOGIC
		);
	END COMPONENT;

-- Signals
-- No required this time because we'll use active-high inputs and outputs


BEGIN

-- Instantiation of up to 4 basic 1-bit adders:

	Chip1	: Circuit_W
		PORT MAP (
-- from component name 	=> to signal or port name
				D	=> D,
				A	=> A,
				B	=> B,
				W	=> W			
		);


	--The active-high not used LED will be set --> OFF
	LED0 <= '0';
	LED1 <= '0';
	LED3 <= '0';
	LED4 <= '0';
	LED5 <= '0';
	LED6 <= '0';
	LED7 <= '0';	
	LED8 <= '0';
	LED9 <= '0';	
	
			 		   	 		 		   	   
END DE10_Lite_MAX10_adaptation;
